# {py:mod}`ngff_zarr._array_split`

```{py:module} ngff_zarr._array_split
```

```{autodoc2-docstring} ngff_zarr._array_split
:allowtitles:
```

## Module Contents

### Functions

````{list-table}
:class: autosummary longtable
:align: left

* - {py:obj}`_array_split <ngff_zarr._array_split._array_split>`
  - ```{autodoc2-docstring} ngff_zarr._array_split._array_split
    :summary:
    ```
````

### API

````{py:function} _array_split(ary, indices_or_sections, axis=0)
:canonical: ngff_zarr._array_split._array_split

```{autodoc2-docstring} ngff_zarr._array_split._array_split
```
````
